@@ -1,4 +1,4 @@
-module.exports = grammar({
+export default grammar({
   name: 'anonymous_error',
   rules: {
     document: $ => repeat(choice('ok', 'ERROR')),
